/*******************************************************************************
* File Name: PORT0.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PORT0.h"


/*******************************************************************************
* Function Name: PORT0_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PORT0_Write(uint8 value) 
{
    uint8 staticBits = (PORT0_DR & (uint8)(~PORT0_MASK));
    PORT0_DR = staticBits | ((uint8)(value << PORT0_SHIFT) & PORT0_MASK);
}


/*******************************************************************************
* Function Name: PORT0_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PORT0_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PORT0_0, mode);
	CyPins_SetPinDriveMode(PORT0_1, mode);
	CyPins_SetPinDriveMode(PORT0_2, mode);
	CyPins_SetPinDriveMode(PORT0_3, mode);
	CyPins_SetPinDriveMode(PORT0_4, mode);
	CyPins_SetPinDriveMode(PORT0_5, mode);
	CyPins_SetPinDriveMode(PORT0_6, mode);
	CyPins_SetPinDriveMode(PORT0_7, mode);
}


/*******************************************************************************
* Function Name: PORT0_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PORT0_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PORT0_Read(void) 
{
    return (PORT0_PS & PORT0_MASK) >> PORT0_SHIFT;
}


/*******************************************************************************
* Function Name: PORT0_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PORT0_ReadDataReg(void) 
{
    return (PORT0_DR & PORT0_MASK) >> PORT0_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PORT0_INTSTAT) 

    /*******************************************************************************
    * Function Name: PORT0_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PORT0_ClearInterrupt(void) 
    {
        return (PORT0_INTSTAT & PORT0_MASK) >> PORT0_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
