/*******************************************************************************
* File Name: PinColumn1.c  
* Version 1.90
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinColumn1.h"


/*******************************************************************************
* Function Name: PinColumn1_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PinColumn1_Write(uint8 value) 
{
    uint8 staticBits = (PinColumn1_DR & (uint8)(~PinColumn1_MASK));
    PinColumn1_DR = staticBits | ((uint8)(value << PinColumn1_SHIFT) & PinColumn1_MASK);
}


/*******************************************************************************
* Function Name: PinColumn1_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PinColumn1_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PinColumn1_0, mode);
}


/*******************************************************************************
* Function Name: PinColumn1_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinColumn1_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinColumn1_Read(void) 
{
    return (PinColumn1_PS & PinColumn1_MASK) >> PinColumn1_SHIFT;
}


/*******************************************************************************
* Function Name: PinColumn1_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinColumn1_ReadDataReg(void) 
{
    return (PinColumn1_DR & PinColumn1_MASK) >> PinColumn1_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinColumn1_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinColumn1_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinColumn1_ClearInterrupt(void) 
    {
        return (PinColumn1_INTSTAT & PinColumn1_MASK) >> PinColumn1_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
