/*******************************************************************************
* File Name: PinColumn3.c  
* Version 1.80
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PinColumn3.h"


/*******************************************************************************
* Function Name: PinColumn3_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PinColumn3_Write(uint8 value) 
{
    uint8 staticBits = (PinColumn3_DR & (uint8)(~PinColumn3_MASK));
    PinColumn3_DR = staticBits | ((uint8)(value << PinColumn3_SHIFT) & PinColumn3_MASK);
}


/*******************************************************************************
* Function Name: PinColumn3_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  None
*
*******************************************************************************/
void PinColumn3_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(PinColumn3_0, mode);
}


/*******************************************************************************
* Function Name: PinColumn3_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PinColumn3_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PinColumn3_Read(void) 
{
    return (PinColumn3_PS & PinColumn3_MASK) >> PinColumn3_SHIFT;
}


/*******************************************************************************
* Function Name: PinColumn3_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PinColumn3_ReadDataReg(void) 
{
    return (PinColumn3_DR & PinColumn3_MASK) >> PinColumn3_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PinColumn3_INTSTAT) 

    /*******************************************************************************
    * Function Name: PinColumn3_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PinColumn3_ClearInterrupt(void) 
    {
        return (PinColumn3_INTSTAT & PinColumn3_MASK) >> PinColumn3_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
