/******************************************************************************
* File Name: Main.c
* Version 1.0
*
* Description:
* This file contains the main function for the CapSense and Timer test for CY8CKIT-030.
*
* Note:
*
* Code tested with:
* PSoC Creator: Production
* Device Tested With: CY8C3866AXI-040
* Compiler    : ARMGCC 4.4.1, ARM RVDS Generic , ARM MDK Generic
*
********************************************************************************
* Copyright (2011), Cypress Semiconductor Corporation. All Rights Reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress)
* and is protected by and subject to worldwide patent protection (United
* States and foreign), United States copyright laws and international treaty
* provisions. Cypress hereby grants to licensee a personal, non-exclusive,
* non-transferable license to copy, use, modify, create derivative works of,
* and compile the Cypress Source Code and derivative works for the sole
* purpose of creating custom software in support of licensee product to be
* used only in conjunction with a Cypress integrated circuit as specified in
* the applicable agreement. Any reproduction, modification, translation,
* compilation, or representation of this software except as specified above 
* is prohibited without the express written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. 
*
* Use of this Software may be limited by and subject to the applicable Cypress
* software license agreement. 
*******************************************************************************/

/******************************************************************************
*                           THEORY OF OPERATION
* This project demonstrates the capsense application using 2 capsense buttons. 
* The button state is displayed on the LCD as on or off. 
* Timer Period can be modified by Capsense buttons between 1 to 500
*
* Hardware connection on the Kit
* Slider - P5[0] - P5[4]
* Button1 - P5[5]
* Button2 - P5[6]
* LCD 2[0-6]
* Pin_Output - P6[2]
******************************************************************************/ 
#include <device.h>

/* Define constants for capsense button and slider */
uint8 flag = 0; // Flag variable is set in ISR
unsigned char j = 50;				// milliseconds delay
uint32 timerperiod = 1000; //60x100 - 24bit'lik sayac icin ve 60dakika icin 360000 uint32 ile saglanabilir
uint32 current;
int dakika = 1;
int dakika_old, dakika_;
#define ON           (1)
#define OFF          (0)
#define NO_FINGER    (0xFF)
//************* New / Changed *******
#define FALSE 0
#define TRUE !FALSE
int x;

//************* New / Changed *******
uint8 Digits[2] = {0,0};			// This are the two digits, 0 is ten, 1 is birlar
CY_ISR_PROTO(SegmentHandler);	// Look into System "Reference Guide"

void segment(int rakam);
void segmentler (int rakam);

void main()
{
    uint8 statusButton0 = OFF;
    uint8 statusButton1 = OFF;
	uint8 statusButton2 = OFF;

	isr_1_Start();	// Configures and Enables the interrupt
	isr_1_ClearPending();
//	Timer_1_Start();
//************* New / Changed *******
	Multiplexer_Start();
	Segment_Int_StartEx(SegmentHandler);
	
    CYGlobalIntEnable; 

    LCD_Start();
    LCD_Position(0,0);
    LCD_PrintString("Btn0 Btn1 Dakika");
	LCD_Position(1, 10);
	LCD_PrintNumber(dakika);
	Pin_Output_Write(OFF);
	dakika_old = dakika;
    /* Start capsense and initialize baselines and enable scan */
    CapSense_Start();
    CapSense_InitializeAllBaselines();
    CapSense_ScanEnabledWidgets();
	


    while(1)
    {
        /* If scanning is completed update the baseline count and check if sensor is active */  
        if(!CapSense_IsBusy())
        {
            /* Update baseline for all the sensors */
            CapSense_UpdateEnabledBaselines();
            CapSense_ScanEnabledWidgets();
        
		
            /* Test if button widget is active */
            statusButton0 = CapSense_CheckIsWidgetActive(CapSense_BUTTON0__BTN);
            statusButton1 = CapSense_CheckIsWidgetActive(CapSense_BUTTON1__BTN);
 			statusButton2 = CapSense_CheckIsWidgetActive(CapSense_BUTTON2__BTN);
			
            /* Display button 1 status on LCD */
            LCD_Position(1,0);
            if( statusButton0 == ON )
            {
                LCD_PrintString("On ");
				dakika--;
				if(dakika <=1)
					dakika =1;				
				// Timer_1_WritePeriod(timerperiod);
//				Pin_1_Write(ON);
				LCD_Position(1, 10);
				LCD_PrintString("  ");			// clean up the previous display
				LCD_Position(1, 10);
				LCD_PrintNumber(dakika);
				dakika_old = dakika;
				CyDelay(500u);
				segmentler (dakika);
				
            }
            else
            {
                LCD_PrintString("Off");
//				Pin_1_Write(OFF);
            }

            /* Display button 1 status on LCD */
            LCD_Position(1,5);
            if( statusButton1 == ON )
            {
                LCD_PrintString("On ");
				dakika++;
				if(dakika >= 60)
					dakika=60;				
				// Timer_1_WritePeriod(timerperiod);
				LCD_Position(1, 10);
				LCD_PrintString("  ");			// clean up the previous display
				LCD_Position(1, 10);
				LCD_PrintNumber(dakika);
				dakika_old = dakika;
				CyDelay(500u);			
				segmentler (dakika);
				
            }
							
            else
            {
                LCD_PrintString("Off");
//				Pin_2_Write(OFF);
            }
			
			
			
			
			

			if( statusButton2 == ON )
            {
               	LCD_Position(0,10);
				LCD_PrintString("-SET- ");
				timerperiod = dakika * 60 * 100;
				Timer_1_WritePeriod(timerperiod);
				Control_Reg_1_Write(1); // Timer ReSet. It resets the period counter to the period value
				Pin_Output_Write(ON);
				CyDelay(500u);
				Control_Reg_1_Write(0); // Timer Setup
				Timer_1_Start();
				
				
            }

			CapSense_ScanEnabledWidgets();		// Rescan for cleaning values

        }
		
		// current dakika value
		current = Timer_1_ReadCounter();
		dakika_ = current / 6000;
		if(dakika_ == (dakika_old-1))
		{
			dakika_old = dakika_;
			LCD_Position(1, 13);
			LCD_PrintString("  ");			// clean up the previous display
			LCD_Position(1, 13);
			LCD_PrintNumber(dakika_);
			
		}
		
		// Timeout
		if(flag == 1)
		{
			flag = 0;
			Timer_1_Stop();
			
			Pin_Output_Write(ON);
			CyDelay(100u);
			Pin_Output_Write(OFF);

			LCD_Position(0,10);
	
          	LCD_PrintString("-STOP-");
			
		}
		

		Pin_Output_Write(OFF);
		
		
    }    

}
/* [] END OF FILE */



void segment(int rakam)
{

//************* New / Changed *******
const uint8 TranslateTable[10] = {	0x3f,0x06,0x5b,0x4f,0x66,
									0x6d,0x7d,0x07,0x7f,0x6f};
	if((rakam < 0) || (rakam > 9)) 	PORT0_Write(0);				// Invalid
	else							PORT0_Write(TranslateTable[rakam]);


/*	
	if(rakam==0)
		PORT0_Write(0x3F);
	else if(rakam==1)
		PORT0_Write(0x06);
	else if(rakam==2)
		PORT0_Write(0x5B);
	else if(rakam==3)
		PORT0_Write(0x4F);
	else if(rakam==4)
		PORT0_Write(0x66);
	else if(rakam==5)
		PORT0_Write(0x6D);
	else if(rakam==6)
		PORT0_Write(0x7D);
	else if(rakam==7)
		PORT0_Write(0x07);
	else if(rakam==8)
		PORT0_Write(0x7F);
	else if(rakam==9)
		PORT0_Write(0x6F);
	else
		PORT0_Write(0x00);
*/

}

void Column_Write(int rakam)
{
	if(rakam==1)
	{
		PinColumn1_Write(1);	
		PinColumn2_Write(0);
		

	}
	else if(rakam==2)
	{
		PinColumn1_Write(0);
		PinColumn2_Write(1);
		
	}
	
	else 	
	{
		PinColumn1_Write(0);
		PinColumn2_Write(0);
		
	}




}


void segmentler (int rakam)
{
//************* New / Changed *******
//	int onlar;
//	int birler;
//	
//	
//	
//	onlar = ((rakam/10)%10);
//	birler = rakam % 10;
//
	Digits[1] = rakam % 10;
	Digits[0] = ((rakam/10)%10);
//	segment(onlar);
//	PinColumn1_Write(1);
//	PinColumn2_Write(0);	
//	CyDelay(10u);
//	
//	segment(birler);
//	PinColumn1_Write(0);
//	PinColumn2_Write(1);
//	CyDelay(10u);
//	
//	
	
}

CY_ISR(SegmentHandler)
{
static uint8 DigitNumber = 0;
//	DigitNumber = DigitNumber?0:1;	// Too Difficult to read
	if(DigitNumber != 0)	DigitNumber = 0;
	else					DigitNumber = 1;
	
	segmentler(Digits[DigitNumber]);
	PinColumn1_Write(!DigitNumber);
	PinColumn2_Write( DigitNumber);
	
}